@@ -73,7 +73,7 @@ class InterstateWireMessage:
         return self._header == o.header and self._payload == o.payload
 
     def __repr__(self) -> str:
-        return "InterstateWireMessage(identity={}, type={}, header={})".format(self._identity, self._type, self._header)
+        return "InterstateWireMessage(identity={}, type={}, header={}, payload={})".format(self._identity, self._type, self._header, self._payload)
 
 
 class InterstateMessageAssembly(ABC):
