@@ -46,8 +46,6 @@ class StreamDemultiplexer(AIOWorkerTask):
                 self._log.debug("Payload sent to subject")
             except DisposedException:
                 self._log.warn("Connection (%s) has already been disposed but not garbage collected", identity)
-                connection.close_inbound()
-                connection.close_outbound()
                 self._con_agent.dump(connection.identity())
             except Exception as e:
                 self._log.warn("Calling on_next produced an exception: %s", ErrorAssembly.exc_message(e))
